@@ -3,9 +3,9 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.04";
+our $VERSION = "1.0.0";
 
-use List::Util qw(any first);
+use List::Util qw(first);
 use List::UtilsBy qw(partition_by sort_by);
 
 use JSON::TypeInference::Type::Array;
@@ -40,7 +40,7 @@ sub infer {
     }
   } @$possible_type_classes ];
 
-  if (_looks_like_maybe($candidate_types)) {
+  if (JSON::TypeInference::Type::Maybe->looks_like_maybe($candidate_types)) {
     my $entity_type = first { ! $_->isa('JSON::TypeInference::Type::Null') } @$candidate_types;
     return JSON::TypeInference::Type::Maybe->new($entity_type);
   } elsif (scalar(@$candidate_types) > 1) {
@@ -50,11 +50,6 @@ sub infer {
   }
 }
 
-sub _looks_like_maybe {
-  my ($candidate_types) = @_;
-  return (scalar(@$candidate_types) == 2) && any { $_->isa('JSON::TypeInference::Type::Null') } @$candidate_types;
-}
-
 # ArrayRef[ArrayRef[Any]] => JSON::TypeInference::Type::Array
 sub _infer_array_element_types {
   my ($class, $dataset) = @_;
@@ -100,25 +95,23 @@ JSON::TypeInference - Inferencing JSON types from given Perl values
       { name => 'nazuna' },
       { name => 'nori' },
     ];
-    my $inferred_type = JSON::TypeInference->infer($data); # object[string, string]
+    my $inferred_type = JSON::TypeInference->infer($data); # object[name:string]
 
 =head1 DESCRIPTION
 
-JSON::TypeInference infers the type of JSON values from the given Perl values.
+C< JSON::TypeInference > infers the type of JSON values from the given Perl values.
 
-If some candidate types of the given Perl values are inferred, JSON::TypeInference reports the type of it as a union type that consists of all candidate types.
+If some candidate types of the given Perl values are inferred, C< JSON::TypeInference > reports the type of it as a union type that consists of all candidate types.
 
 =head1 CLASS METHODS
 
 =over 4
 
-=item infer
-
-    JSON::TypeInference->infer($dataset: ArrayRef[Any]); # => JSON::TypeInference::Type
+=item C<< infer($dataset: ArrayRef[Any]); # => JSON::TypeInference::Type >>
 
 To infer the type of JSON values from the given values.
 
-Return value is a instance of JSON::TypeInference::Type that means the inferred JSON type.
+Return value is a instance of C< JSON::TypeInference::Type > that means the inferred JSON type.
 
 =back
 
@@ -133,5 +126,9 @@ it under the same terms as Perl itself.
 
 aereal E<lt>aereal@aereal.orgE<gt>
 
+=head1 SEE ALSO
+
+L<JSON::TypeInference::Type>
+
 =cut
 
