@@ -1,14 +1,10 @@
 package JSON::TypeInference::Type::Boolean;
 use strict;
 use warnings;
+use parent qw(JSON::TypeInference::Type::Atom);
 
 use Types::Serialiser;
 
-sub new {
-  my ($class) = @_;
-  return bless {}, $class;
-}
-
 sub name {
   my ($class) = @_;
   return 'boolean';
@@ -30,7 +26,7 @@ JSON::TypeInference::Type::Boolean - JSON boolean type
 
 =head1 DESCRIPTION
 
-JSON::TypeInference::Type::Boolean represents JSON boolean type.
+C< JSON::TypeInference::Type::Boolean > represents JSON boolean type.
 
 It is a value type, and so has no parameters.
 
