@@ -1,14 +1,10 @@
 package JSON::TypeInference::Type::Number;
 use strict;
 use warnings;
+use parent qw(JSON::TypeInference::Type::Atom);
 
 use Scalar::Util qw(looks_like_number);
 
-sub new {
-  my ($class) = @_;
-  return bless {}, $class;
-}
-
 sub name {
   my ($class) = @_;
   return 'number';
@@ -30,7 +26,7 @@ JSON::TypeInference::Type::Number - JSON number type
 
 =head1 DESCRIPTION
 
-JSON::TypeInference::Type::Number represents JSON number type.
+C< JSON::TypeInference::Type::Number > represents JSON number type.
 
 It is a value type, and so has no parameters.
 
