@@ -22,6 +22,13 @@ sub accepts {
   return ref($data) eq 'HASH';
 }
 
+sub signature {
+  my ($self) = @_;
+  my @sorted_keys = sort keys %{$self->properties};
+  my @prop_signatures = map { join ':', $_, $self->properties->{$_}->signature } @sorted_keys;
+  return sprintf 'object[%s]', join ', ', @prop_signatures;
+}
+
 1;
 __END__
 
@@ -33,7 +40,7 @@ JSON::TypeInference::Type::Object - JSON object type
 
 =head1 DESCRIPTION
 
-JSON::TypeInference::Type::Object represents JSON object type.
+C< JSON::TypeInference::Type::Object > represents JSON object type.
 
 It is a container type, and has some type parameters on each properties.
 
