@@ -1,14 +1,10 @@
 package JSON::TypeInference::Type::String;
 use strict;
 use warnings;
+use parent qw(JSON::TypeInference::Type::Atom);
 
 use Scalar::Util qw(looks_like_number);
 
-sub new {
-  my ($class) = @_;
-  return bless {}, $class;
-}
-
 sub name {
   my ($class) = @_;
   return 'string';
@@ -30,7 +26,7 @@ JSON::TypeInference::Type::String - JSON string type
 
 =head1 DESCRIPTION
 
-JSON::TypeInference::Type::String represents JSON string type.
+C< JSON::TypeInference::Type::String > represents JSON string type.
 
 It is a value type, and so has no parameters.
 
